==> untangled-client-0.6.1-20161215.183334-3.jar: public/js/cards/out/untangled/client/impl/util.js <==
// Compiled by ClojureScript 1.9.293 {}
goog.provide('untangled.client.impl.util');
goog.require('cljs.core');
goog.require('cljs.pprint');
goog.require('cljs.spec');
goog.require('om.next');
untangled.client.impl.util.deep_merge = (function untangled$client$impl$util$deep_merge(var_args){
var args__28503__auto__ = [];
var len__28496__auto___61046 = arguments.length;
var i__28497__auto___61047 = (0);
while(true){
if((i__28497__auto___61047 < len__28496__auto___61046)){
args__28503__auto__.push((arguments[i__28497__auto___61047]));

var G__61048 = (i__28497__auto___61047 + (1));
i__28497__auto___61047 = G__61048;
continue;
} else {
}
break;
}

var argseq__28504__auto__ = ((((0) < args__28503__auto__.length))?(new cljs.core.IndexedSeq(args__28503__auto__.slice((0)),(0),null)):null);
return untangled.client.impl.util.deep_merge.cljs$core$IFn$_invoke$arity$variadic(argseq__28504__auto__);
});

untangled.client.impl.util.deep_merge.cljs$core$IFn$_invoke$arity$variadic = (function (xs){

if(cljs.core.every_QMARK_.call(null,cljs.core.map_QMARK_,xs)){
return cljs.core.apply.call(null,cljs.core.merge_with,untangled.client.impl.util.deep_merge,xs);
} else {
return cljs.core.last.call(null,xs);
}
});

untangled.client.impl.util.deep_merge.cljs$lang$maxFixedArity = (0);

untangled.client.impl.util.deep_merge.cljs$lang$applyTo = (function (seq61045){
return untangled.client.impl.util.deep_merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.seq.call(null,seq61045));
});

/**
 * Helper for logging the app-state. Pass in an untangled application atom and either top-level keys, data-paths
 *     (like get-in), or both.
 */
untangled.client.impl.util.log_app_state = (function untangled$client$impl$util$log_app_state(var_args){
var args__28503__auto__ = [];
var len__28496__auto___61055 = arguments.length;
var i__28497__auto___61056 = (0);
while(true){
if((i__28497__auto___61056 < len__28496__auto___61055)){
args__28503__auto__.push((arguments[i__28497__auto___61056]));

var G__61057 = (i__28497__auto___61056 + (1));
i__28497__auto___61056 = G__61057;
continue;
} else {
}
break;
}

var argseq__28504__auto__ = ((((1) < args__28503__auto__.length))?(new cljs.core.IndexedSeq(args__28503__auto__.slice((1)),(0),null)):null);
return untangled.client.impl.util.log_app_state.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__28504__auto__);
});

untangled.client.impl.util.log_app_state.cljs$core$IFn$_invoke$arity$variadic = (function (app_atom,keys_and_paths){
try{var app_state = om.next.app_state.call(null,new cljs.core.Keyword(null,"reconciler","reconciler",-1832826966).cljs$core$IFn$_invoke$arity$1(cljs.core.deref.call(null,app_atom)));
return cljs.pprint.pprint.call(null,(function (){var make_path = ((function (app_state){
return (function untangled$client$impl$util$make_path(location){
if(cljs.core.sequential_QMARK_.call(null,location)){
return location;
} else {
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [location], null);
}
});})(app_state))
;
var process_location = ((function (app_state){
return (function untangled$client$impl$util$process_location(acc,location){
var path = make_path.call(null,location);
return cljs.core.assoc_in.call(null,acc,path,cljs.core.get_in.call(null,cljs.core.deref.call(null,app_state),path));
});})(app_state))
;
var pred__61052 = cljs.core._EQ_;
var expr__61053 = cljs.core.count.call(null,keys_and_paths);
if(cljs.core.truth_(pred__61052.call(null,(0),expr__61053))){
return cljs.core.deref.call(null,app_state);
} else {
if(cljs.core.truth_(pred__61052.call(null,(1),expr__61053))){
return cljs.core.get_in.call(null,cljs.core.deref.call(null,app_state),make_path.call(null,cljs.core.first.call(null,keys_and_paths)));
} else {
return cljs.core.reduce.call(null,process_location,cljs.core.PersistentArrayMap.EMPTY,keys_and_paths);
}
}
})());
}catch (e61051){if((e61051 instanceof Error)){
var e = e61051;
throw cljs.core.ex_info.call(null,"untangled.client.impl.util/log-app-state expects an atom with an untangled client",cljs.core.PersistentArrayMap.EMPTY);
} else {
throw e61051;

}
}});

untangled.client.impl.util.log_app_state.cljs$lang$maxFixedArity = (1);

untangled.client.impl.util.log_app_state.cljs$lang$applyTo = (function (seq61049){
var G__61050 = cljs.core.first.call(null,seq61049);
var seq61049__$1 = cljs.core.next.call(null,seq61049);
return untangled.client.impl.util.log_app_state.cljs$core$IFn$_invoke$arity$variadic(G__61050,seq61049__$1);
});


//# sourceMappingURL=util.js.map?rel=1481754437242

==> untangled-client-0.6.1-20170119.164423-4.jar: public/js/cards/out/untangled/client/impl/util.js <==
// Compiled by ClojureScript 1.9.293 {}
goog.provide('untangled.client.impl.util');
goog.require('cljs.core');
goog.require('cljs.pprint');
goog.require('cljs.spec');
goog.require('om.next');
untangled.client.impl.util.atom_QMARK_ = (function untangled$client$impl$util$atom_QMARK_(a){
return (a instanceof cljs.core.Atom);
});
untangled.client.impl.util.deep_merge = (function untangled$client$impl$util$deep_merge(var_args){
var args__28503__auto__ = [];
var len__28496__auto___219572 = arguments.length;
var i__28497__auto___219573 = (0);
while(true){
if((i__28497__auto___219573 < len__28496__auto___219572)){
args__28503__auto__.push((arguments[i__28497__auto___219573]));

var G__219574 = (i__28497__auto___219573 + (1));
i__28497__auto___219573 = G__219574;
continue;
} else {
}
break;
}

var argseq__28504__auto__ = ((((0) < args__28503__auto__.length))?(new cljs.core.IndexedSeq(args__28503__auto__.slice((0)),(0),null)):null);
return untangled.client.impl.util.deep_merge.cljs$core$IFn$_invoke$arity$variadic(argseq__28504__auto__);
});

untangled.client.impl.util.deep_merge.cljs$core$IFn$_invoke$arity$variadic = (function (xs){

if(cljs.core.every_QMARK_.call(null,cljs.core.map_QMARK_,xs)){
return cljs.core.apply.call(null,cljs.core.merge_with,untangled.client.impl.util.deep_merge,xs);
} else {
return cljs.core.last.call(null,xs);
}
});

untangled.client.impl.util.deep_merge.cljs$lang$maxFixedArity = (0);

untangled.client.impl.util.deep_merge.cljs$lang$applyTo = (function (seq219571){
return untangled.client.impl.util.deep_merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.seq.call(null,seq219571));
});

/**
 * Helper for logging the app-state. Pass in an untangled application atom and either top-level keys, data-paths
 * (like get-in), or both.
 */
untangled.client.impl.util.log_app_state = (function untangled$client$impl$util$log_app_state(var_args){
var args__28503__auto__ = [];
var len__28496__auto___219581 = arguments.length;
var i__28497__auto___219582 = (0);
while(true){
if((i__28497__auto___219582 < len__28496__auto___219581)){
args__28503__auto__.push((arguments[i__28497__auto___219582]));

var G__219583 = (i__28497__auto___219582 + (1));
i__28497__auto___219582 = G__219583;
continue;
} else {
}
break;
}

var argseq__28504__auto__ = ((((1) < args__28503__auto__.length))?(new cljs.core.IndexedSeq(args__28503__auto__.slice((1)),(0),null)):null);
return untangled.client.impl.util.log_app_state.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__28504__auto__);
});

untangled.client.impl.util.log_app_state.cljs$core$IFn$_invoke$arity$variadic = (function (app_atom,keys_and_paths){
try{var app_state = om.next.app_state.call(null,new cljs.core.Keyword(null,"reconciler","reconciler",-1832826966).cljs$core$IFn$_invoke$arity$1(cljs.core.deref.call(null,app_atom)));
return cljs.pprint.pprint.call(null,(function (){var make_path = ((function (app_state){
return (function untangled$client$impl$util$make_path(location){
if(cljs.core.sequential_QMARK_.call(null,location)){
return location;
} else {
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [location], null);
}
});})(app_state))
;
var process_location = ((function (app_state){
return (function untangled$client$impl$util$process_location(acc,location){
var path = make_path.call(null,location);
return cljs.core.assoc_in.call(null,acc,path,cljs.core.get_in.call(null,cljs.core.deref.call(null,app_state),path));
});})(app_state))
;
var pred__219578 = cljs.core._EQ_;
var expr__219579 = cljs.core.count.call(null,keys_and_paths);
if(cljs.core.truth_(pred__219578.call(null,(0),expr__219579))){
return cljs.core.deref.call(null,app_state);
} else {
if(cljs.core.truth_(pred__219578.call(null,(1),expr__219579))){
return cljs.core.get_in.call(null,cljs.core.deref.call(null,app_state),make_path.call(null,cljs.core.first.call(null,keys_and_paths)));
} else {
return cljs.core.reduce.call(null,process_location,cljs.core.PersistentArrayMap.EMPTY,keys_and_paths);
}
}
})());
}catch (e219577){if((e219577 instanceof Error)){
var e = e219577;
throw cljs.core.ex_info.call(null,"untangled.client.impl.util/log-app-state expects an atom with an untangled client",cljs.core.PersistentArrayMap.EMPTY);
} else {
throw e219577;

}
}});

untangled.client.impl.util.log_app_state.cljs$lang$maxFixedArity = (1);

untangled.client.impl.util.log_app_state.cljs$lang$applyTo = (function (seq219575){
var G__219576 = cljs.core.first.call(null,seq219575);
var seq219575__$1 = cljs.core.next.call(null,seq219575);
return untangled.client.impl.util.log_app_state.cljs$core$IFn$_invoke$arity$variadic(G__219576,seq219575__$1);
});


//# sourceMappingURL=util.js.map?rel=1483481836849
